@@ -177,6 +177,9 @@ yaml_syck_parser_handler
                 }
             } else if (strEQ( id, "null" )) {
                 sv = newSV(0);
+            } else if (strnEQ( id, "str", 3 )) {
+                sv = newSVpvn(n->data.str->ptr, n->data.str->len);
+                CHECK_UTF8;
             } else if (strEQ( id, "bool#yes" )) {
                 sv = newSVsv(&PL_sv_yes);
             } else if (strEQ( id, "bool#no" )) {
@@ -554,8 +557,7 @@ yaml_syck_parser_handler
                 if (hv_store_ent(map, key, val, 0) != NULL)
                     USE_OBJECT(val);
                 sv = newRV_noinc((SV*)map);
-                if ( load_blessed )
-                    sv_bless(sv, gv_stashpv("YAML::Syck::BadAlias", TRUE));
+                sv_bless(sv, gv_stashpv("YAML::Syck::BadAlias", TRUE));
             }
             else
 #endif
